(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     32875,        782]
NotebookOptionsPosition[     31929,        745]
NotebookOutlinePosition[     32270,        760]
CellTagsIndexPosition[     32227,        757]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Running in the Rain Demonstration", "Title"],

Cell[TextData[{
 "This notebook is a supplement to the article by Dank Hailman and Bruce \
Torrents, \"Keeping Dry: The Mathematics of Running in the Rain\", ",
 StyleBox["Mathematics Magazine",
  FontSlant->"Italic"],
 ",",
 StyleBox[" 82",
  FontWeight->"Bold"],
 "(4), Oct. 2009."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", ",", "scaleFactor", ",", "opt", ",", 
       RowBox[{"dx", "=", ".1"}], ",", 
       RowBox[{"dy", "=", ".5"}], ",", 
       RowBox[{"smax", "=", "20"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"shape", "\[Equal]", "\"\<ellipsoid\>\""}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"f", "=", 
          FractionBox[
           RowBox[{"\[Pi]", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["y", "2"], " ", 
               SuperscriptBox["z", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"s", "-", "w1"}], ")"}], "2"]}], "+", 
              RowBox[{
               SuperscriptBox["x", "2"], 
               SuperscriptBox["z", "2"], " ", 
               SuperscriptBox["w2", "2"]}], " ", "+", 
              RowBox[{
               SuperscriptBox["x", "2"], 
               SuperscriptBox["y", "2"], " ", 
               SuperscriptBox["k", "2"]}]}]]}], "s"]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"scaleFactor", "=", "\[Pi]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"opt", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"w1", "\[LessEqual]", "0"}], ",", 
            RowBox[{"smax", "+", "1"}], 
            RowBox[{"(*", " ", "infinity", " ", "*)"}], ",", 
            FractionBox[
             RowBox[{
              RowBox[{
               SuperscriptBox["x", "2"], " ", 
               SuperscriptBox["y", "2"], " ", 
               SuperscriptBox["k", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["y", "2"], " ", 
               SuperscriptBox["z", "2"], " ", 
               SuperscriptBox["w1", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["x", "2"], " ", 
               SuperscriptBox["z", "2"], " ", 
               SuperscriptBox["w2", "2"]}]}], 
             RowBox[{
              SuperscriptBox["y", "2"], " ", 
              SuperscriptBox["z", "2"], " ", "w1"}]]}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"f", "=", 
          RowBox[{
           FractionBox["4", "s"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"y", " ", "z", " ", 
              RowBox[{"Abs", "[", 
               RowBox[{"s", "-", "w1"}], "]"}]}], "+", 
             RowBox[{"x", " ", "z", " ", 
              RowBox[{"Abs", "[", "w2", "]"}]}], "+", 
             RowBox[{"k", " ", "x", " ", "y"}]}], ")"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"scaleFactor", "=", "4"}], ";", "\[IndentingNewLine]", 
         RowBox[{"opt", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"w1", "<", 
             RowBox[{"x", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"Abs", "[", "w2", "]"}], "/", "y"}], "+", 
                RowBox[{"k", "/", "z"}]}], ")"}]}]}], ",", 
            RowBox[{"smax", "+", "1"}], 
            RowBox[{"(*", " ", "infinity", " ", "*)"}], ",", "w1"}], 
           "]"}]}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Grid", "[", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", "labels", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<The traveler\>\"", ",", "\"\<Label\>\""}], "]"}], 
           ",", 
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Optimal pace shown in green (if finite)\>\"", ",", 
             "\"\<Label\>\""}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"(*", " ", 
           RowBox[{"left", " ", "panel"}], " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Graphics3D", "[", 
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"shape", "\[Equal]", "\"\<ellipsoid\>\""}], ",", 
                 RowBox[{"GeometricTransformation", "[", 
                  RowBox[{
                   RowBox[{"Sphere", "[", "]"}], ",", 
                   RowBox[{"ScalingTransform", "[", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Cuboid", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "x"}], ",", 
                    RowBox[{"-", "y"}], ",", 
                    RowBox[{"-", "z"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], 
                "]"}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"GrayLevel", "[", ".9", "]"}], ",", 
                 RowBox[{"Polygon", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "2"}], ",", 
                    RowBox[{"-", "8"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "2", ",", 
                    RowBox[{"-", "8"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2", ",", 
                    RowBox[{"-", "8"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "4", ",", 
                    RowBox[{"-", "8"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"8", ",", "0", ",", 
                    RowBox[{"-", "8"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "4"}], ",", 
                    RowBox[{"-", "8"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", 
                    RowBox[{"-", "2"}], ",", 
                    RowBox[{"-", "8"}]}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
              "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
             
             RowBox[{"Ticks", "\[Rule]", "False"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"\"\<\!\(\*
StyleBox[\"x\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"y\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"z\",
FontSlant->\"Italic\"]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", "8"}]}], "]"}], 
           "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{"right", " ", "panel"}], " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", 
            RowBox[{"f", ",", 
             RowBox[{"{", 
              RowBox[{"s", ",", ".1", ",", "smax"}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "6"}], ",", "smax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "16"}], ",", "60"}], "}"}]}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"GrayLevel", "[", ".5", "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Ticks", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
             RowBox[{"AxesOrigin", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<\!\(\*
StyleBox[\"s\",
FontSlant->\"Italic\"]\) = speed of travel\>\"", ",", "9"}], "]"}], ",", 
                RowBox[{"Style", "[", 
                 RowBox[{"\"\<\!\(\*
StyleBox[\"T\",
FontSlant->\"Italic\"]\) = total wetness\>\"", ",", "9"}], "]"}]}], "}"}]}], 
             ",", "\[IndentingNewLine]", 
             RowBox[{"AspectRatio", "\[Rule]", 
              RowBox[{"1", "/", "2"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Epilog", "\[Rule]", "\[IndentingNewLine]", 
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Line", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"w1", ",", 
                    RowBox[{"-", "dy"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"w1", ",", "dy"}], "}"}]}], "}"}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Text", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                   "\"\<w\!\(\*SubscriptBox[\(\[ThinSpace]\), \(t\)]\)\>\"", 
                    ",", "9", ",", 
                    RowBox[{"FontSlant", "\[Rule]", "\"\<Italic\>\""}]}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"w1", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "1.5"}], "}"}]}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Text", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{"\"\<\[UpArrow]\>\"", ",", "12", ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    RowBox[{"Darker", "[", 
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], "]"}]}]}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"opt", ",", 
                    RowBox[{"-", "10"}]}], "}"}]}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Text", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{"opt", ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "9", 
                    ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    RowBox[{"Darker", "[", 
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], "]"}]}]}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"opt", ",", 
                    RowBox[{"-", "14"}]}], "}"}]}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Darker", "[", 
                   RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], "]"}], ",", 
                  RowBox[{"Line", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"opt", ",", 
                    RowBox[{"-", "dy"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"opt", ",", "dy"}], "}"}]}], "}"}], "]"}]}], 
                 "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Darker", "[", 
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "1", ",", "0"}], "]"}], "]"}], ",", 
                    RowBox[{"PointSize", "[", ".015", "]"}]}], "]"}], ",", 
                  RowBox[{"Point", "[", 
                   RowBox[{"{", 
                    RowBox[{"opt", ",", 
                    RowBox[{"f", "/.", 
                    RowBox[{"s", "\[Rule]", "opt"}]}]}], "}"}], "]"}]}], 
                 "}"}], ",", "\[IndentingNewLine]", 
                RowBox[{"Text", "[", 
                 RowBox[{
                  RowBox[{"Style", "[", 
                   RowBox[{
                    RowBox[{"scaleFactor", "\"\<y\[VeryThinSpace]z \>\""}], 
                    ",", "9", ",", 
                    RowBox[{"FontSlant", "\[Rule]", "\"\<Italic\>\""}]}], 
                   "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", 
                    RowBox[{"scaleFactor", " ", "y", " ", "z"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"1.3", ",", "0"}], "}"}]}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Hue", "[", "1", "]"}], ",", 
                  RowBox[{"Line", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"scaleFactor", " ", "y", " ", "z"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"smax", ",", " ", 
                    RowBox[{"scaleFactor", " ", "y", " ", "z"}]}], "}"}]}], 
                    "}"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", "}"}]}]}],
             "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}]}], 
        "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "shape", ",", "\"\<rectangular solid\>\"", ",", 
       "\"\<shape of traveler\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<rectangular solid\>\"", ",", " ", "\"\<ellipsoid\>\""}], 
      "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<dimensions of traveler\>\"", ",", "Larger"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", ".5", ",", "\"\<x\>\""}], "}"}], ",", ".1", ",", "8", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y", ",", "1", ",", "\"\<y\>\""}], "}"}], ",", ".1", ",", "8", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z", ",", "3", ",", "\"\<z\>\""}], "}"}], ",", ".1", ",", "8", 
     ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<components of rain velocity\>\"", ",", "Larger"}], "]"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w1", ",", "5", ",", "\"\<tail wind \!\(\*SubscriptBox[
StyleBox[\"w\",
FontSlant->\"Italic\"], 
RowBox[{\"\[ThinSpace]\", \"t\"}]]\)\>\""}], "}"}], ",", 
     RowBox[{"-", "5"}], ",", "14", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w2", ",", "0", ",", "\"\<cross wind \!\(\*SubscriptBox[
StyleBox[\"w\",
FontSlant->\"Italic\"], \"c\"]\)\>\""}], "}"}], ",", "0", ",", "30", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", "12", ",", "\"\<vertical speed of rain\>\""}], "}"}], 
     ",", "5", ",", "15", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Top"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.461488576002763*^9, 3.461488621274811*^9}, {
   3.461488674380074*^9, 3.461488702018951*^9}, {3.46148877954834*^9, 
   3.461488791529448*^9}, {3.4614890327210712`*^9, 3.461489041893346*^9}, {
   3.461489083474338*^9, 3.4614890945871363`*^9}, 3.461489147510192*^9},
 CellID->123518597],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`k$$ = 12, $CellContext`shape$$ = 
    "ellipsoid", $CellContext`w1$$ = 3.0999999999999996`, $CellContext`w2$$ = 
    0, $CellContext`x$$ = 1.1400000000000001`, $CellContext`y$$ = 
    1.9900000000000002`, $CellContext`z$$ = 5.7, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`shape$$], "rectangular solid", 
       "shape of traveler"}, {"rectangular solid", "ellipsoid"}}, {
      Hold[
       Style["dimensions of traveler", Larger]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`x$$], 0.5, "x"}, 0.1, 8}, {{
       Hold[$CellContext`y$$], 1, "y"}, 0.1, 8}, {{
       Hold[$CellContext`z$$], 3, "z"}, 0.1, 8}, {
      Hold[
       Style["components of rain velocity", Larger]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`w1$$], 5, 
       "tail wind \!\(\*SubscriptBox[\n StyleBox[\"w\",\n\
FontSlant->\"Italic\"], \n RowBox[{\"\[ThinSpace]\", \"t\"}]]\)"}, -5, 14}, {{
      
       Hold[$CellContext`w2$$], 0, 
       "cross wind \!\(\*SubscriptBox[\n StyleBox[\"w\",\nFontSlant->\"Italic\
\"], \"c\"]\)"}, 0, 30}, {{
       Hold[$CellContext`k$$], 12, "vertical speed of rain"}, 5, 15}}, 
    Typeset`size$$ = {588., {100.34375, 105.65625}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`shape$150214$$ = False, $CellContext`x$150215$$ = 
    0, $CellContext`y$150216$$ = 0, $CellContext`z$150217$$ = 
    0, $CellContext`w1$150218$$ = 0, $CellContext`w2$150219$$ = 
    0, $CellContext`k$150220$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`k$$ = 12, $CellContext`shape$$ = 
        "rectangular solid", $CellContext`w1$$ = 5, $CellContext`w2$$ = 
        0, $CellContext`x$$ = 0.5, $CellContext`y$$ = 1, $CellContext`z$$ = 
        3}, "ControllerVariables" :> {
        Hold[$CellContext`shape$$, $CellContext`shape$150214$$, False], 
        Hold[$CellContext`x$$, $CellContext`x$150215$$, 0], 
        Hold[$CellContext`y$$, $CellContext`y$150216$$, 0], 
        Hold[$CellContext`z$$, $CellContext`z$150217$$, 0], 
        Hold[$CellContext`w1$$, $CellContext`w1$150218$$, 0], 
        Hold[$CellContext`w2$$, $CellContext`w2$150219$$, 0], 
        Hold[$CellContext`k$$, $CellContext`k$150220$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`f$, $CellContext`scaleFactor$, $CellContext`opt$, \
$CellContext`dx$ = 0.1, $CellContext`dy$ = 0.5, $CellContext`smax$ = 20}, 
        If[$CellContext`shape$$ == 
          "ellipsoid", $CellContext`f$ = 
           Pi ((($CellContext`y$$^2 $CellContext`z$$^2) ($CellContext`s - \
$CellContext`w1$$)^2 + ($CellContext`x$$^2 $CellContext`z$$^2) \
$CellContext`w2$$^2 + ($CellContext`x$$^2 $CellContext`y$$^2) \
$CellContext`k$$^2)^Rational[1, 2]/$CellContext`s); $CellContext`scaleFactor$ = 
           Pi; $CellContext`opt$ = 
           If[$CellContext`w1$$ <= 0, $CellContext`smax$ + 
             1, (($CellContext`x$$^2 $CellContext`y$$^2) $CellContext`k$$^2 + \
($CellContext`y$$^2 $CellContext`z$$^2) $CellContext`w1$$^2 + \
($CellContext`x$$^2 $CellContext`z$$^2) \
$CellContext`w2$$^2)/(($CellContext`y$$^2 $CellContext`z$$^2) \
$CellContext`w1$$)], $CellContext`f$ = (
             4/$CellContext`s) (($CellContext`y$$ $CellContext`z$$) 
              Abs[$CellContext`s - $CellContext`w1$$] + ($CellContext`x$$ \
$CellContext`z$$) 
              Abs[$CellContext`w2$$] + ($CellContext`k$$ $CellContext`x$$) \
$CellContext`y$$); $CellContext`scaleFactor$ = 4; $CellContext`opt$ = 
           If[$CellContext`w1$$ < $CellContext`x$$ (
               Abs[$CellContext`w2$$]/$CellContext`y$$ + \
$CellContext`k$$/$CellContext`z$$), $CellContext`smax$ + 
             1, $CellContext`w1$$]]; Grid[{{
            Style["The traveler", "Label"], 
            Style["Optimal pace shown in green (if finite)", "Label"]}, {
            Graphics3D[{
              If[$CellContext`shape$$ == "ellipsoid", 
               GeometricTransformation[
                Sphere[], 
                
                ScalingTransform[{$CellContext`x$$, $CellContext`y$$, \
$CellContext`z$$}]], 
               
               Cuboid[{-$CellContext`x$$, -$CellContext`y$$, \
-$CellContext`z$$}, {$CellContext`x$$, $CellContext`y$$, $CellContext`z$$}]], {
               GrayLevel[0.9], 
               
               Polygon[{{0, -2, -8}, {0, 2, -8}, {4, 2, -8}, {4, 4, -8}, {8, 
                0, -8}, {4, -4, -8}, {4, -2, -8}}]}}, Axes -> True, Ticks -> 
             False, AxesLabel -> {
              "\!\(\*\nStyleBox[\"x\",\nFontSlant->\"Italic\"]\)", 
               "\!\(\*\nStyleBox[\"y\",\nFontSlant->\"Italic\"]\)", 
               "\!\(\*\nStyleBox[\"z\",\nFontSlant->\"Italic\"]\)"}, 
             PlotRange -> 8], 
            
            Plot[$CellContext`f$, {$CellContext`s, 0.1, $CellContext`smax$}, 
             PlotRange -> {{-6, $CellContext`smax$}, {-16, 60}}, PlotStyle -> 
             GrayLevel[0.5], Ticks -> None, AxesOrigin -> {0, 0}, AxesLabel -> {
               Style[
               "\!\(\*\nStyleBox[\"s\",\nFontSlant->\"Italic\"]\) = speed of \
travel", 9], 
               Style[
               "\!\(\*\nStyleBox[\"T\",\nFontSlant->\"Italic\"]\) = total \
wetness", 9]}, AspectRatio -> 1/2, ImageSize -> 400, Epilog -> {
               
               Line[{{$CellContext`w1$$, -$CellContext`dy$}, \
{$CellContext`w1$$, $CellContext`dy$}}], 
               Text[
                Style[
                "w\!\(\*SubscriptBox[\(\[ThinSpace]\), \(t\)]\)", 9, 
                 FontSlant -> "Italic"], {$CellContext`w1$$, 0}, {0, 1.5}], 
               Text[
                Style["\[UpArrow]", 12, FontColor -> Darker[
                   RGBColor[0, 1, 0]]], {$CellContext`opt$, -10}], 
               Text[
                Style[
                 ToString[
                  NumberForm[$CellContext`opt$, {4, 2}]], 9, FontColor -> 
                 Darker[
                   RGBColor[0, 1, 0]]], {$CellContext`opt$, -14}], {
                Darker[
                 RGBColor[0, 1, 0]], 
                
                Line[{{$CellContext`opt$, -$CellContext`dy$}, \
{$CellContext`opt$, $CellContext`dy$}}]}, {
                Directive[
                 Darker[
                  RGBColor[0, 1, 0]], 
                 PointSize[0.015]], 
                Point[{$CellContext`opt$, 
                  
                  ReplaceAll[$CellContext`f$, $CellContext`s -> \
$CellContext`opt$]}]}, 
               Text[
                
                Style[$CellContext`scaleFactor$ "y\[VeryThinSpace]z ", 9, 
                 FontSlant -> "Italic"], {
                0, ($CellContext`scaleFactor$ $CellContext`y$$) \
$CellContext`z$$}, {1.3, 0}], {
                Hue[1], 
                
                Line[{{0, ($CellContext`scaleFactor$ $CellContext`y$$) \
$CellContext`z$$}, {$CellContext`smax$, ($CellContext`scaleFactor$ \
$CellContext`y$$) $CellContext`z$$}}]}}]}}]], 
      "Specifications" :> {{{$CellContext`shape$$, "rectangular solid", 
          "shape of traveler"}, {"rectangular solid", "ellipsoid"}}, 
        Style[
        "dimensions of traveler", Larger], {{$CellContext`x$$, 0.5, "x"}, 0.1,
          8, Appearance -> "Labeled"}, {{$CellContext`y$$, 1, "y"}, 0.1, 8, 
         Appearance -> "Labeled"}, {{$CellContext`z$$, 3, "z"}, 0.1, 8, 
         Appearance -> "Labeled"}, Delimiter, 
        Style[
        "components of rain velocity", 
         Larger], {{$CellContext`w1$$, 5, 
          "tail wind \!\(\*SubscriptBox[\n StyleBox[\"w\",\n\
FontSlant->\"Italic\"], \n RowBox[{\"\[ThinSpace]\", \"t\"}]]\)"}, -5, 14, 
         Appearance -> 
         "Labeled"}, {{$CellContext`w2$$, 0, 
          "cross wind \!\(\*SubscriptBox[\n StyleBox[\"w\",\n\
FontSlant->\"Italic\"], \"c\"]\)"}, 0, 30, Appearance -> 
         "Labeled"}, {{$CellContext`k$$, 12, "vertical speed of rain"}, 5, 15,
          Appearance -> "Labeled"}}, "Options" :> {ControlPlacement -> Top}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{631., {251.34375, 256.65625}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.35696210375764*^9, 3.461488543228744*^9, {3.4614885973009987`*^9, 
   3.4614886257436857`*^9}, {3.4614887035430813`*^9, 3.4614887309127703`*^9}, 
   3.461488808513867*^9, {3.46148903329137*^9, 3.4614890426079187`*^9}, {
   3.4614890869340563`*^9, 3.461489095613491*^9}, 3.4614891495466347`*^9},
 CellID->1198580894]
}, {2}]],

Cell[TextData[{
 "To stay driest, is it better to walk or run in the rain? The conventional \
wisdom was conveyed in limerick by Matthew Wright in ",
 StyleBox["New Scientist",
  FontSlant->"Italic"],
 " magazine in 1995: \"When caught in the rain without mac, walk as fast as \
the wind at your back. But when the wind's in your face, the optimal pace is \
as fast as your legs will make track.\" But this advice is only partially \
correct. Yes, in the absence of a tail-wind, running flat out is best. But \
\"as fast as the wind at your back\" is misleading. It is the best pace for \
box-shaped travelers provided the tail-wind is sufficiently strong. But if \
the tail-wind is too weak, or if you are a more well-rounded individual (in \
appearance, at least), then your optimal pace ",
 StyleBox["exceeds",
  FontSlant->"Italic"],
 " that of the tail wind."
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4614892259552794`*^9, 3.461489305897656*^9}, {
   3.461490342618395*^9, 3.461490361809032*^9}, {3.46149039708781*^9, 
   3.461490954433282*^9}, {3.461493191474596*^9, 3.4614931960342712`*^9}, {
   3.461493260063501*^9, 3.46149326945121*^9}, {3.461494520150463*^9, 
   3.461494542633445*^9}}],

Cell[TextData[{
 "This demonstration calculates total wetness for box-shaped and ellipsoidal \
travelers moving in a straight line in prescribed rain conditions. The \
wetness measure is simply the volume of the ",
 StyleBox["rain region",
  FontSlant->"Italic"],
 ", the region in space containing all the drops that will strike the \
traveler as he moves a distance of one unit in the positive x direction (his \
direction of travel is indicated by the large arrow in the left frame). Total \
wetness is graphed in the right panel as a function of the traveler's speed, \
and the optimal speed of travel is shown in green provided that it is \
finite."
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.46149090278603*^9, 3.461490907413842*^9}, {
   3.461490976596477*^9, 3.461491138779463*^9}, {3.4614911741235027`*^9, 
   3.4614912253486853`*^9}, {3.461491264395813*^9, 3.461491275785636*^9}, {
   3.461491343853404*^9, 3.4614914824250526`*^9}, 3.461491932933859*^9, {
   3.461492107388136*^9, 3.4614921533684483`*^9}, {3.461493055437763*^9, 
   3.461493056279955*^9}, {3.461494617945046*^9, 3.4614946207929907`*^9}},
 CellID->1152476598],

Cell["\<\
It is interesting to note that for ellipsoidal travelers, the optimal pace is \
very sensitive to changes in the x dimension of the traveler. Chubby \
travelers seem better served by running faster. For rectangular travelers, \
minor perturbations in the x dimension make no difference whatever.\
\>", "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.461493057467655*^9, 3.461493169654764*^9}, {
   3.461493201839147*^9, 3.461493207095434*^9}},
 CellID->308102811],

Cell[TextData[{
 "The \"dimensions of traveler\" controls set the lengths of the semi-axes of \
an ellipsoidal traveler, and half the lengths of the sides of a \
rectangular-solid traveler. The area of the front face of a rectangular-solid \
traveler is therefore ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "y", " ", "z"}], TraditionalForm]], "InlineMath",
  FormatType->"TraditionalForm"],
 ", while the corresponding projection for an ellipsoidal traveler is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Pi]", " ", "y", " ", "z"}], TraditionalForm]], "InlineMath",
  FormatType->"TraditionalForm"],
 ". If the traveler moves one unit forward at super-speed, the rain region \
approaches a horizontal cylinder whose volume approaches these values. Hence \
total wetness is asymptotic to the red line shown."
}], "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.461491505819511*^9, 3.46149190008118*^9}, {
   3.461492254747415*^9, 3.461492284941967*^9}, {3.4614926567475*^9, 
   3.46149267149918*^9}},
 CellID->1519170293],

Cell["\<\
Complete derivations of the wetness functions can be found in our article.\
\>", "Text",
 CellID->1262035268],

Cell[TextData[{
 "A version of this demonstration made for the free ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Player application can be downloaded from the Wolfram Demonstrations \
Project here:\n",
 ButtonBox["http://demonstrations.wolfram.com/RunningInTheRain/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/RunningInTheRain/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/RunningInTheRain/"]
}], "Text"],

Cell["Wright's limerick was first published here:", "Text",
 CellChangeTimes->{
  3.35696210375764*^9, {3.4614923631996517`*^9, 3.461492386519165*^9}, 
   3.461492496008677*^9},
 CellID->1527694163],

Cell[TextData[{
 "Matthew Wright, Letter to the editor, ",
 StyleBox["New Scientist",
  FontSlant->"Italic"],
 ", ",
 StyleBox["1960",
  FontWeight->"Bold"],
 ", 1995, p.57."
}], "Text",
 CellID->641314009],

Cell["\<\
Comments may be addressed to Bruce Torrence.
btorrenc@rmc.edu\
\>", "Text"]
}, Open  ]]
},
WindowSize->{808, 766},
WindowMargins->{{Automatic, 406}, {Automatic, 30}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 50, 0, 76, "Title"],
Cell[620, 24, 295, 9, 41, "Text"],
Cell[CellGroupData[{
Cell[940, 37, 16758, 399, 1136, "Input",
 CellID->123518597],
Cell[17701, 438, 9227, 182, 525, "Output",
 CellID->1198580894]
}, {2}]],
Cell[26940, 623, 1214, 22, 101, "Text"],
Cell[28157, 647, 1150, 20, 71, "Text",
 CellID->1152476598],
Cell[29310, 669, 479, 9, 41, "Text",
 CellID->308102811],
Cell[29792, 680, 1027, 22, 71, "Text",
 CellID->1519170293],
Cell[30822, 704, 119, 3, 26, "Text",
 CellID->1262035268],
Cell[30944, 709, 471, 11, 56, "Text"],
Cell[31418, 722, 198, 4, 26, "Text",
 CellID->1527694163],
Cell[31619, 728, 206, 9, 26, "Text",
 CellID->641314009],
Cell[31828, 739, 85, 3, 41, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
